module PingableIpamPlugin
  class Engine < ::Rails::Engine
    engine_name 'pingable_ipam_plugin'

    config.autoload_paths += Dir["#{config.root}/app/models/concerns"]
    config.autoload_paths += Dir["#{config.root}/app/services"]

    initializer 'pingable_ipam_plugin.register_plugin', :before => :finisher_hook do |_app|
      Foreman::Plugin.register :pingable_ipam_plugin do
        requires_foreman '>= 1.16'
      end
    end

    # Include concerns in this config.to_prepare block
    config.to_prepare do
      begin
        ::IPAM.send(:include, PingableIpamPlugin::IpamExtensions)
        ::Subnet::Ipv4.singleton_class.send(:prepend, PingableIpamPlugin::Ipv4Extensions)
        ::Nic::Base.send(:include, PingableIpamPlugin::NicExtensions)
      rescue => e
        Rails.logger.warn "PingableIpamPlugin: skipping engine hook (#{e})"
      end
    end

    initializer 'pingable_ipam_plugin.register_gettext', after: :load_config_initializers do |_app|
      locale_dir = File.join(File.expand_path('../../..', __FILE__), 'locale')
      locale_domain = 'pingable_ipam_plugin'
      Foreman::Gettext::Support.add_text_domain locale_domain, locale_dir
    end
  end
end
